@@ -1,25 +1,23 @@
-/***************************************************************************
-    copyright            : (C) 2004 by Scott Wheeler
-    email                : wheeler@kde.org
-    copyright            : (c) 2007 by Michael Pyne
-    email                : michael.pyne@kdemail.net
- ***************************************************************************/
+/**
+ * Copyright (C) 2004 Scott Wheeler <wheeler@kde.org>
+ * Copyright (C) 2007 Michael Pyne <mpyne@kde.org>
+ */
 
-/***************************************************************************
- *   This library is free software; you can redistribute it and/or modify  *
- *   it  under the terms of the GNU Lesser General Public License version  *
- *   2.1 as published by the Free Software Foundation.                     *
- *                                                                         *
- *   This library is distributed in the hope that it will be useful, but   *
- *   WITHOUT ANY WARRANTY; without even the implied warranty of            *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU     *
- *   Lesser General Public License for more details.                       *
- *                                                                         *
- *   You should have received a copy of the GNU Lesser General Public      *
- *   License along with this library; if not, write to the Free Software   *
- *   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA         *
- *   02110-1301, USA                                                       *
- ***************************************************************************/
+/**
+ *   This library is free software; you can redistribute it and/or modify
+ *   it  under the terms of the GNU Lesser General Public License version
+ *   2.1 as published by the Free Software Foundation.
+ *
+ *   This library is distributed in the hope that it will be useful, but
+ *   WITHOUT ANY WARRANTY; without even the implied warranty of
+ *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ *   Lesser General Public License for more details.
+ *
+ *   You should have received a copy of the GNU Lesser General Public
+ *   License along with this library; if not, write to the Free Software
+ *   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
+ *   02110-1301, USA
+ */
 
 #include "ktrm.h"
 #include <config-juk.h>
