@@ -1,23 +1,20 @@
-/***************************************************************************
-    begin                : Sat Feb 14 2004
-    copyright            : (C) 2004 by Scott Wheeler
-    email                : wheeler@kde.org
-
-    copyright            : (C) 2007 by Matthias Kretz
-    email                : kretz@kde.org
-
-    copyright            : (C) 2008, 2009 by Michael Pyne
-    email                : michael.pyne@kdemail.net
-***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+/**
+ * Copyright (C) 2004 Scott Wheeler <wheeler@kde.org>
+ * Copyright (C) 2007 Matthias Kretz <kretz@kde.org>
+ * Copyright (C) 2008, 2009 Michael Pyne <mpyne@kde.org>
+ *
+ * This program is free software; you can redistribute it and/or modify it under
+ * the terms of the GNU General Public License as published by the Free Software
+ * Foundation; either version 2 of the License, or (at your option) any later
+ * version.
+ *
+ * This program is distributed in the hope that it will be useful, but WITHOUT ANY
+ * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
+ * PARTICULAR PURPOSE. See the GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License along with
+ * this program.  If not, see <http://www.gnu.org/licenses/>.
+ */
 
 #include "playermanager.h"
 
@@ -461,7 +458,7 @@ void PlayerManager::slotFinished()
     }
     else {
         emit signalItemChanged(m_file);
-        m_media[m_curOutputPath]->setCurrentSource(m_file.absFilePath());
+        m_media[m_curOutputPath]->setCurrentSource(QUrl::fromLocalFile(m_file.absFilePath()));
         m_media[m_curOutputPath]->play();
     }
 }
@@ -670,7 +667,7 @@ void PlayerManager::crossfadeToFile(const FileHandle &newFile)
     m_fader[nextOutputPath]->setVolume(0.0f);
 
     emit signalItemChanged(newFile);
-    m_media[nextOutputPath]->setCurrentSource(newFile.absFilePath());
+    m_media[nextOutputPath]->setCurrentSource(QUrl::fromLocalFile(newFile.absFilePath()));
     m_media[nextOutputPath]->play();
 
     m_fader[m_curOutputPath]->setVolume(1.0f);
