@@ -1,19 +1,19 @@
-/****************************************************************************************
- * Copyright (c) 2009 Nikolaj Hald Nielsen <nhn@kde.org>                                *
- * Copyright (c) 2009 Mark Kretschmann <kretschmann@kde.org>                            *
- *                                                                                      *
- * This program is free software; you can redistribute it and/or modify it under        *
- * the terms of the GNU General Public License as published by the Free Software        *
- * Foundation; either version 2 of the License, or (at your option) any later           *
- * version.                                                                             *
- *                                                                                      *
- * This program is distributed in the hope that it will be useful, but WITHOUT ANY      *
- * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A      *
- * PARTICULAR PURPOSE. See the GNU General Public License for more details.             *
- *                                                                                      *
- * You should have received a copy of the GNU General Public License along with         *
- * this program.  If not, see <http://www.gnu.org/licenses/>.                           *
- ****************************************************************************************/
+/**
+ * Copyright (c) 2009 Nikolaj Hald Nielsen <nhn@kde.org>
+ * Copyright (c) 2009 Mark Kretschmann <kretschmann@kde.org>
+ *
+ * This program is free software; you can redistribute it and/or modify it under
+ * the terms of the GNU General Public License as published by the Free Software
+ * Foundation; either version 2 of the License, or (at your option) any later
+ * version.
+ *
+ * This program is distributed in the hope that it will be useful, but WITHOUT ANY
+ * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
+ * PARTICULAR PURPOSE. See the GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License along with
+ * this program.  If not, see <http://www.gnu.org/licenses/>.
+ */
 
 #include "volumepopupbutton.h"
 #include "slider.h"
@@ -106,7 +106,7 @@ VolumePopupButton::volumeChanged( float newVolume )
     else
         setIcon( KIcon( "audio-volume-high" ) );
 
-    m_volumeLabel->setText( QString::number( int( newVolume * 100 ) ) + '%' );
+    m_volumeLabel->setText( i18n( "%1%" , int( newVolume * 100 ) ) );
 
     if( newVolume != m_volumeSlider->value() )
         m_volumeSlider->setValue( newVolume * 100 );
@@ -126,7 +126,7 @@ VolumePopupButton::muteStateChanged( bool muted )
     {
         const float volume = JuK::JuKInstance()->playerManager()->volume();
         setIcon( KIcon( "audio-volume-muted" ) );
-        setToolTip( i18n( "Volume: %1% %2", int( 100 * volume ), i18n( "(muted)" ) ) );
+        setToolTip( i18n( "Volume: %1% (muted)", int( 100 * volume ) ) );
     }
     else
     {
@@ -162,10 +162,9 @@ VolumePopupButton::wheelEvent( QWheelEvent * event )
 {
     event->accept();
     PlayerManager *player = JuK::JuKInstance()->playerManager();
-    float volume = qBound( 0.0, player->volume() + float( event->delta() ) / 4000.0, 1.0 );
+    float volume = qBound( 0.0f, player->volume() + float( event->delta() ) / 4000.0f, 1.0f );
     player->setVolume( volume );
     volumeChanged( volume );
 }
 
 #include "volumepopupbutton.moc"
-
